From 5400dce120a0d3ebacba91cb94b0a9a78e959c82 Mon Sep 17 00:00:00 2001
From: Walter Van Herck <w.van.herck@fz-juelich.de>
Date: Tue, 19 Jun 2012 16:19:08 +0200
Subject: [PATCH] Renamed DWBA formfactor test to IsGISAXS3 test

---
 App/App.pro                                      |  4 ++--
 .../{TestDWBAFormFactor.h => TestIsGISAXS3.h}    | 16 ++++++++--------
 App/src/TestFactory.cpp                          |  4 ++--
 ...{TestDWBAFormFactor.cpp => TestIsGISAXS3.cpp} | 12 ++++++------
 4 files changed, 18 insertions(+), 18 deletions(-)
 rename App/inc/{TestDWBAFormFactor.h => TestIsGISAXS3.h} (75%)
 rename App/src/{TestDWBAFormFactor.cpp => TestIsGISAXS3.cpp} (95%)

diff --git a/App/App.pro b/App/App.pro
index df5dbda5926..14ce8db0845 100644
--- a/App/App.pro
+++ b/App/App.pro
@@ -11,7 +11,7 @@ SOURCES += \
     src/DrawHelper.cpp \
     src/TestFormFactor.cpp \
     src/TestRoughness.cpp \
-    src/TestDWBAFormFactor.cpp \
+    src/TestIsGISAXS3.cpp \
     src/SampleFactory.cpp \
     src/StandardSamples.cpp \
     src/CommandLine.cpp \
@@ -28,7 +28,7 @@ HEADERS += \
     inc/AppLinkDef.h \
     inc/TestFormFactor.h \
     inc/TestRoughness.h \
-    inc/TestDWBAFormFactor.h \
+    inc/TestIsGISAXS3.h \
     inc/SampleFactory.h \
     inc/StandardSamples.h \
     inc/CommandLine.h \
diff --git a/App/src/TestFactory.cpp b/App/src/TestFactory.cpp
index db8a29acecb..c320891ad4c 100644
--- a/App/src/TestFactory.cpp
+++ b/App/src/TestFactory.cpp
@@ -2,8 +2,8 @@
 #include "TestRoughness.h"
 #include "TestFresnelCoeff.h"
 #include "TestFormFactor.h"
-#include "TestDWBAFormFactor.h"
 #include "TestDiffuseReflection.h"
+#include "TestIsGISAXS3.h"
 #include "TestIsGISAXS10.h"
 #include "TestConvolution.h"
 
@@ -18,8 +18,8 @@ TestFactory::TestFactory() : m_benchmark(0)
     registerItem("roughness",  IFactoryCreateFunction<TestRoughness, IFunctionalTest> );
     registerItem("fresnel",    IFactoryCreateFunction<TestFresnelCoeff, IFunctionalTest> );
     registerItem("formfactor", IFactoryCreateFunction<TestFormFactor, IFunctionalTest> );
-    registerItem("dwba",       IFactoryCreateFunction<TestDWBAFormFactor, IFunctionalTest> );
     registerItem("diffuse",    IFactoryCreateFunction<TestDiffuseReflection, IFunctionalTest> );
+    registerItem("isgisaxs3",  IFactoryCreateFunction<TestIsGISAXS3, IFunctionalTest> );
     registerItem("isgisaxs10", IFactoryCreateFunction<TestIsGISAXS10, IFunctionalTest> );
     registerItem("convolution", IFactoryCreateFunction<TestConvolution, IFunctionalTest> );
 
diff --git a/App/src/TestDWBAFormFactor.cpp b/App/src/TestIsGISAXS3.cpp
similarity index 95%
rename from App/src/TestDWBAFormFactor.cpp
rename to App/src/TestIsGISAXS3.cpp
index be81c1923a8..de8c896bc02 100644
--- a/App/src/TestDWBAFormFactor.cpp
+++ b/App/src/TestIsGISAXS3.cpp
@@ -1,4 +1,4 @@
-#include "TestDWBAFormFactor.h"
+#include "TestIsGISAXS3.h"
 #include "IsGISAXSTools.h"
 #include "Types.h"
 #include "Units.h"
@@ -13,7 +13,7 @@
 
 
 
-TestDWBAFormFactor::TestDWBAFormFactor()
+TestIsGISAXS3::TestIsGISAXS3()
     : m_dwba_ff(new FormFactorCylinder(5*Units::nanometer, 5*Units::nanometer))
 {
 	complex_t n_substrate(1.0-6e-6, 2e-8);
@@ -28,12 +28,12 @@ TestDWBAFormFactor::TestDWBAFormFactor()
     mp_intensity_output->addAxis(p_z_axis);
 }
 
-TestDWBAFormFactor::~TestDWBAFormFactor()
+TestIsGISAXS3::~TestIsGISAXS3()
 {
     delete mp_intensity_output;
 }
 
-void TestDWBAFormFactor::execute()
+void TestIsGISAXS3::execute()
 {
     MultiIndex& index = mp_intensity_output->getIndex();
     NamedVector<double> *p_y_axis = dynamic_cast<NamedVector<double>*>(mp_intensity_output->getAxis("detector y-axis"));
@@ -60,7 +60,7 @@ void TestDWBAFormFactor::execute()
     write();
 }
 
-void TestDWBAFormFactor::draw()
+void TestIsGISAXS3::draw()
 {
     // creation of 2D histogram from calculated intensities
     TCanvas *c1 = new TCanvas("c1_test_dwba_formfactor", "Cylinder Formfactor", 0, 0, 1024, 768);
@@ -100,7 +100,7 @@ void TestDWBAFormFactor::draw()
     p_hist2D->Draw("CONT4 Z");
 }
 
-void TestDWBAFormFactor::write()
+void TestIsGISAXS3::write()
 {
     std::ofstream file;
     file.open("./IsGISAXS_examples/ex-3/dwbacyl.ima", std::ios::out);
diff --git a/App/inc/TestDWBAFormFactor.h b/App/inc/TestIsGISAXS3.h
similarity index 75%
rename from App/inc/TestDWBAFormFactor.h
rename to App/inc/TestIsGISAXS3.h
index ef51db4fada..515f316b6ff 100644
--- a/App/inc/TestDWBAFormFactor.h
+++ b/App/inc/TestIsGISAXS3.h
@@ -1,5 +1,5 @@
-#ifndef TESTDWBAFORMFACTOR_H_
-#define TESTDWBAFORMFACTOR_H_
+#ifndef TESTISGISAXS3_H_
+#define TESTISGISAXS3_H_
 // ********************************************************************
 // * The BornAgain project                                            *
 // * Simulation of neutron and x-ray scattering at grazing incidence  *
@@ -9,8 +9,8 @@
 // * eget quam orci. Quisque  porta  varius  dui,  quis  posuere nibh *
 // * mollis quis. Mauris commodo rhoncus porttitor.                   *
 // ********************************************************************
 //! @file   TestDWBAFormFactor.h
 //! @brief  Definition of TestDWBAFormFactor class for formfactor validation
 //! @author herk
 //! @date   02.05.2012
 
@@ -20,11 +20,11 @@
 #include "DWBAFormFactor.h"
 
 
-class TestDWBAFormFactor : public IFunctionalTest
+class TestIsGISAXS3 : public IFunctionalTest
 {
 public:
-    TestDWBAFormFactor();
-    virtual ~TestDWBAFormFactor();
+    TestIsGISAXS3();
+    virtual ~TestIsGISAXS3();
     virtual void execute();
     void draw();
     void write();
@@ -33,4 +33,4 @@ private:
     OutputData<double> *mp_intensity_output;
     DWBAFormFactor m_dwba_ff;
 };
-#endif /* TESTDWBAFORMFACTOR_H_ */
+#endif /* TESTISGISAXS3_H_ */
@@ -9,8 +9,8 @@
 // * mollis quis. Mauris commodo rhoncus porttitor.                   *
 // ********************************************************************
-//! @file   TestDWBAFormFactor.h
-//! @brief  Definition of TestDWBAFormFactor class for formfactor validation
+//! @file   TestIsGISAXS3.h
+//! @brief  Definition of TestIsGISAXS3 class for IsGISAXS validation
 //! @author herk
 //! @date   02.05.2012
-- 
GitLab